@@ -99,7 +99,7 @@ class RobotRoboCopDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
             if extension_config.exclude:
                 config.exclude = set(extension_config.exclude)
             if extension_config.configurations:
-                config.configure = set(extension_config.configurations)
+                config.configure = extension_config.configurations
 
             class MyRobocop(Robocop):
                 async def run_check(self, ast_model, filename, source=None):  # type: ignore
@@ -191,6 +191,9 @@ class RobotRoboCopDiagnosticsProtocolPart(RobotLanguageServerProtocolPart):
         if version < (4, 1):
             return CodeDescription(href=f"{base}/rules.html#{issue.name}-{issue.severity.value}{issue.rule_id}".lower())
 
-        return CodeDescription(
-            href=f"{base}/rules_list.html#{issue.name}-{issue.severity.value}{issue.rule_id}".lower()
-        )
+        if version < (4, 1, 1):
+            return CodeDescription(
+                href=f"{base}/rules_list.html#{issue.name}-{issue.severity.value}{issue.rule_id}".lower()
+            )
+
+        return CodeDescription(href=f"{base}/rules_list.html#{issue.name}".lower())
